#!/bin/bash

#
# Sites' Code changes calculation file
#
# This file receives the two filenames of previous and current versions of
# the same site and performs a differentiation. Returns the percentage of how
# simmilar both are.
#
# LICENSE: WTFPL – Do What the Fuck You Want to Public License.
# That is available through the world-wide-web at the following URI:
# http://www.wtfpl.net/
#
# @category   Security
# @package    Yari-Module
# @author     Paul F. Bernal B. <paul.bernal@cedia.org.ec>
# @copyright  2013-2014 Paul F. Bernal B.
# @license    http://www.wtfpl.net/  WTFPL
# @version    0.9
#

################################################################################
# FUNCTIONS SECTION
showUsage() {
  cat <<AYUDA
Uso: $0 <file1.html> <file2.html> [-i]
Ejemplo: $0 sitioV1.html sitioV2.html (Floating point results)
         $0 sitioV1.html sitioV2.html -i (Integer results)
AYUDA
}

################################################################################
# MAIN SECTION

# Check if at most two parameters has been passed by
[ $# -gt 1 ] || { showUsage; exit 1; };

# Calculate the total lines number in first (original) file
lnTotal=$(wc -l $1|awk {'print $1'})
# Calculate the number of common lines
lnComm=$(comm -12 --nocheck-order $1 $2|wc -l)
# Calculate the difference
lnChgd=$(($lnTotal-$lnComm))

# Calculate the percentage of changes in code:
func=$lnChgd*100/$lnTotal
if [ "$3" = "-i" ]; then
	# For integer results
	retval=$(($func))
else
	# For floating point results
	retval=`echo "scale=4;$func"|bc -l`
fi

# pints out the result
echo $retval

exit 0
