#!/bin/bash

#
# Sites' Image changes calculation file
#
# This file receives the two filenames of previous and current versions of
# the same site and performs a differentiation. Returns the percentage of how
# different both are.
#
# LICENSE: WTFPL – Do What the Fuck You Want to Public License.
# That is available through the world-wide-web at the following URI:
# http://www.wtfpl.net/
#
# @category   Security
# @package    Yari-Module
# @author     Paul F. Bernal B. <paul.bernal@cedia.org.ec>
# @copyright  2013-2014 Paul F. Bernal B.
# @license    http://www.wtfpl.net/  WTFPL
# @version    0.9
#

################################################################################
# FUNCTIONS SECTION
showUsage() {
  cat <<AYUDA
Uso: $0 <file1.png> <file2.png> [-i]
Ejemplo: $0 sitioV1.png sitioV2.png (Just gets diff value)
         $0 sitioV1.png sitioV2.png -i (Generates diff image)
AYUDA
}

################################################################################
# MAIN SECTION

# Check if at most two parameters has been passed by
[ $# -gt 1 ] || { showUsage; exit 1; };

# Some var definitions/calculations
filePath=$(dirname $1)
file1=$(basename $1)
file2=$(basename $2)
outFileName=$filePath/${file1%.*}-${file2%.*}.png  # get and joins the parts before the dot
tmpFileName="/tmp/deleteMeIfYouFindMe.png"

file1Size=$(identify $1|awk {'print $3'}|awk -Fx {'print $1'*'$2'})
file2Size=$(identify $2|awk {'print $3'}|awk -Fx {'print $1'*'$2'})

# Since comparing different sized images introduces noise
# We crop the bigest to the smallest one's size
if [ $file2Size -gt $file1Size ]; then
	# If file2 is gretaer, crops it
	smallSizeString=$(identify $1|awk {'print $4'})
	convert $2 -crop $smallSizeString $tmpFileName
elif [ $file1Size -gt $file2Size ]; then
	# If file1 is gretaer, crops it
	smallSizeString=$(identify $2|awk {'print $4'})
	convert $1 -crop $smallSizeString $tmpFileName
else
	# If they both have same size just assing the one provided
	tmpFileName=$2
fi

# Calculate the total changed value
retval=$(convert $1 $tmpFileName -compose Difference -composite -colorspace gray -format '%[fx:mean*100]' info:)

# And generates the image if thirth parameter provided
if [ "$3" = "-i" ]; then
	compare -dissimilarity-threshold 1 $1 $tmpFileName $outFileName 2>&1
fi

[ -n "$smallSizeString" ] && { rm -f $tmpFileName; };

# pints out the result
echo $retval

exit 0
