<?php
/**
 * CheckSites command line script for Unix/Linux.
 *
 * This is the script for cheking changes in sites.
 *
 * @author Paul Bernal <paul.bernal@cedia.org.ec>
 */

class CheckSitesCommand extends CConsoleCommand {

	private $sites = null;
	private $dataPath = null;
	private $date = null;

	public function run($args) {
		# Loads the sites list in sites property	
		$this->getSites();
		# Set some properties
		$this->dataPath = Yii::app()->getBasePath() . '/../data';
		$this->date->today = (isset($args[1])) ? $args[1] : date( 'Ymd' );
		$this->date->yesterday = (isset($args[0])) ? $args[0] : date('Ymd', strtotime($this->date->today . ' - 1 day'));
		# Checks each site in list
		$this->check();
		exit( 0 );
	}
	
	private function check() {
		foreach( $this->sites as $site ) {
			$siteV1Path = "{$this->dataPath}/{$this->date->yesterday}/{$site->url}";
			$siteV2Path = "{$this->dataPath}/{$this->date->today}/{$site->url}";
			$check = new Check();
			$check->siteId = $site->id;
			$check->codeChange = exec( "getCodeChanges.sh $siteV1Path.html $siteV2Path.html" );
			$check->imgChange = exec( "getImageChanges.sh $siteV1Path.png $siteV2Path.png -i" );
			if( $check->save() ) {
				echo "Insertado: siteID={$check->siteId} - url={$site->url} - codeChange={$check->codeChange} - imgChange={$check->imgChange}\n";
				$this->sendAlert( $site, $check );
			}
			else
				print_r( $check->getErrors() );

		}
	}
	
	private function sendAlert( $site, $check ) {
		$sitePreferences = json_decode( $site->preferences );
		$codeAlert	= ( $check->codeChange >= $sitePreferences->codeThreshold ) ? true : false;
		$imgAlert	= ( $check->imgChange >= $sitePreferences->imgThreshold ) ? true : false;
		# If some value exceded threshold
		if( $codeAlert || $imgAlert ) {
			$mail = new JPhpMailer;
			if( isset( Yii::app()->params['SMTP'] ) ) {
				$mail->IsSMTP();
				foreach( Yii::app()->params['SMTP'] as $var => $val )
					$mail->$var = $val;
			}
			$mail->SetFrom(Yii::app()->params['adminEmail'], 'Qhaway');
			$mail->Subject = 'Alerta de cambios en su sitio ' . $site->url;
			$mail->Body = 'Su sitio web ha registrado cambios que han superado al menos uno de los límites establecidos:

Cambios en código (límite=' . $sitePreferences->codeThreshold . '): ' . $check->codeChange . '%
Cambios en imagen (límite=' . $sitePreferences->imgThreshold . '): ' . $check->imgChange . '%

--
Qhaway,
El sistema automático de detección y reporte de defacements.';
			#$mail->MsgHTML('<h1>JUST A TEST!</h1>');
			$mail->AddAddress($site->client->email, $site->client->name);
			$mail->Send();
		}
	}
	
	private function getSites() {
		$sModel = new Site();
		$this->sites = $sModel->findAll();
	}

}
