<?php

/**
 * This is the model class for table "Site".
 *
 * The followings are the available columns in table 'Site':
 * @property integer $id
 * @property integer $clientId
 * @property string $name
 * @property string $url
 * @property string $preferences
 * @property string $insDate
 * @property string $state
 *
 * The followings are the available model relations:
 * @property Client $client
 */
class Site extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Site';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('clientId, name, url', 'required'),
			array('clientId', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>128),
			array('url', 'length', 'max'=>256),
			array('state', 'length', 'max'=>1),
			array('preferences', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, clientId, name, url, preferences, insDate, state', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'client' => array(self::BELONGS_TO, 'Client', 'clientId'),
			'checks' => array(self::HAS_MANY, 'Check', 'siteId', 'order'=>'insDate DESC'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'Cod',
			'clientId' => 'Cliente',
			'name' => 'Nombre',
			'url' => 'Url',
			'preferences' => 'Preferencias',
			'insDate' => 'Registro',
			'state' => 'Estado',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search($clientId=null)
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$clientId = ( $clientId ) ? $clientId : $this->clientId;
		$criteria->compare('clientId',$clientId,true);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('url',$this->url,true);
		$criteria->compare('preferences',$this->preferences,true);
		$criteria->compare('insDate',$this->insDate,true);
		$criteria->compare('state',$this->state,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Site the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	public function getClientFullName() {
		return $this->client->name;
	}
	
	public function getDecodedPrefs() {
		$prefs = json_decode( $this->preferences );
		return "Límite Código: {$prefs->codeThreshold} | Límite Imagen: {$prefs->imgThreshold}";
	}
	
}
